Learn R Programming

mi4p (version 1.3)

rubin2.all: Computes the 2nd Rubin's rule (all peptides)

Description

Computes the total variance-covariance component in the 2nd Rubin's rule for all peptides.

Usage

rubin2.all(
  data,
  metacond,
  funcmean = meanImp_emmeans,
  funcvar = within_variance_comp_emmeans,
  is.parallel = FALSE,
  verbose = FALSE
)

Value

List of variance-covariance matrices.

Arguments

data

dataset

metacond

a factor to specify the groups

funcmean

function that should be used to compute the mean

funcvar

function that should be used to compute the variance

is.parallel

should parallel computing be used?

verbose

should messages be displayed?

Author

Frédéric Bertrand

References

M. Chion, Ch. Carapito and F. Bertrand (2021). Accounting for multiple imputation-induced variability for differential analysis in mass spectrometry-based label-free quantitative proteomics. tools:::Rd_expr_doi("doi:10.1371/journal.pcbi.1010420").

Examples

Run this code
library(mi4p)
data(datasim)
datasim_imp <- multi.impute(data = datasim[,-1], conditions = 
attr(datasim,"metadata")$Condition, method = "MLE")
rubin2.all(datasim_imp[1:5,,],attr(datasim,"metadata")$Condition)

Run the code above in your browser using DataLab