A data frame with the simulated and attribute metadata.
Arguments
iii
A parameter useful to loop over for simulated lists of datasets. It has no effect.
nobs
Number of peptides
nobs1
Number of peptides with differential expressions between the two conditions
ng1
Number of biological replicates in condition A
ng2
Number of biological replicates in condition B
mg1
Mean in condition A
mg2
Mean in condition B
dispg1
Dispersion in condition A
dispg2
Dispersion in condition B
References
M. Chion, Ch. Carapito and F. Bertrand (2021). Accounting for multiple imputation-induced variability for differential analysis in mass spectrometry-based label-free quantitative proteomics. tools:::Rd_expr_doi("doi:10.1371/journal.pcbi.1010420").